<div align="center">
  <h1>dcc-js</h1>
  <p>A typed JavaScript library for parsing and writing DCCs</p>
</div>
<br />

## Heads-Up

This library does not validate the given DCC. It expects them to be valid against the supported DCC schema.
If you are looking for a way to validate xml against a xsd in the browser, have a look at the GEMIMEG Tool.


## Getting Started

The module is currently published to a private registry on this GitLab instance.
To install it you have to create a `.npmrc` in the root of your project with the following content.

```
@d-ptb:registry=https://gitlab1.ptb.de/api/v4/packages/npm/

# the following auth token is a public read only one
//gitlab1.ptb.de/api/v4/projects/:_authToken=yyhHC6-HhSZ8zxu4BS-_
//gitlab1.ptb.de/api/v4/packages/npm/:_authToken=yyhHC6-HhSZ8zxu4BS-_
//gitlab1.ptb.de/api/v4/projects/105/packages/npm/:_authToken=yyhHC6-HhSZ8zxu4BS-_
```

After that you can run `npm install @d-ptb/dcc-js`.


## Example

```js
import { DCCDocument } from "@d-ptb/dcc-js";

// parse the xml
const xml = "<valid dcc xml>";
const doc = DCCDocument.fromXml(xml);

// access the properties of the DCC
// _attr contains all the attributes of a given element
doc.digitalCalibrationCertificate._attr.schemaVersion // => 3.1.2
// _text is used to access the value of the given element
doc.digitalCalibrationCertificate.administrativeData.coreData.uniqueIdentifier._text

// serialize the DCC
console.log(doc.toXML()); // => <valid dcc xml>
```

## License

Copyright 2021 Physikalisch-Technische Bundesanstalt, Bundesallee 100, 38116 Braunschweig, GERMANY
Licensed under the EUPL, Version 1.2 or – as soon they will be approved by the European Commission - subsequent versions of the EUPL (the "Licence");

You may not use this work except in compliance with the Licence.

You may obtain a copy of the Licence at: https://joinup.ec.europa.eu/software/page/eupl

Unless required by applicable law or agreed to in writing, software distributed under the Licence is
distributed on an "AS IS" basis, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
express or implied.

See [the Licence](LICENSE.md) for the specific language governing permissions and limitations under the Licence.


## Publishing this package

Add the following to your `.npmrc`.
```
message="chore(release): bump version to v%s"
# if you want to sign the tag
sign-git-tag=true

@d-ptb:registry=https://gitlab1.ptb.de/api/v4/packages/npm/

# the following auth token should be a private one with write permission for the package registry
//gitlab1.ptb.de/api/v4/projects/:_authToken=<token>
//gitlab1.ptb.de/api/v4/packages/npm/:_authToken=<token>
//gitlab1.ptb.de/api/v4/projects/105/packages/npm/:_authToken=<token>

```


### Publishing workflow

1. Commit all changes
2. Bump the version with `npm version [major | minor | patch | ...]`
3. Push all commits to the remote
4. Publish the package with `npm publish`
