/*
 * Ensures a given value is wrapped in an array.
 * If the value is null, an empty array is returned.
 * */
export function ensureArray<T>(value: undefined | T | T[]): T[] {
  // return empty array if value is null
  if (value == null) return [];

  // return the value if it is an array
  if (Array.isArray(value)) return value;

  // if it is a single element, wrap it with an array
  return [value];
}

export function removeFromArray<T>(arr: T[], ...items: T[]) {
  for (const item of items) {
    const index = arr.indexOf(item);
    if (index !== -1) {
      arr.splice(index, 1);
    }
  }
}
